import Path from 'path';
import {app, ipcMain, BrowserWindow} from "electron";
import packageConfig from "../package.json"

class AppController extends Object{
    private mainWindow: BrowserWindow;
    constructor() {
        super();
        app.setName(packageConfig.config.appname);
        app.on('activate', this.activate);
        app.on('ready', this.createWindow);
        app.on('window-all-closed', this.windowAllClosed);
    }

    createWindow = () => {
        this.mainWindow = new BrowserWindow({
            webPreferences:{
                nodeIntegration:false,
                contextIsolation:true,
                preload:Path.join(__dirname,'./preload.js')
        },
            width:800, height:600,
        });
        this.mainWindow.loadFile("./renderer/renderer.html")
            .then(
                () => console.log("success load front"),
                () => console.log("fail load front")
            );
        this.mainWindow.webContents.openDevTools({mode:"detach"});
        this.mainWindow.on('closed', ()=>{
            this.mainWindow = null;
        })
    }

    windowAllClosed = () =>{
        if(process.platform !== 'darwin'){
            app.quit();
        }
    }

    activate = () => {
        if(this.mainWindow === null){
            this.createWindow();
        }
    }
}

ipcMain.handle('get-version',()=>{
    return process.versions;
})

ipcMain.handle('get-app-name',()=>{
    return app.getName();
})

const myApp = new AppController();