const path = require('path')
const CopyWebpackPlugin = require('copy-webpack-plugin');
const VueLoaderPlugin = require('vue-loader/lib/plugin');
const HtmlWebpackPlugin  = require('html-webpack-plugin');
const merge = require("webpack-merge").merge;

let copyWebpack_for_main = new CopyWebpackPlugin({
    patterns:[
        {
            from: "package.json",
            to: "./",
            context: "./src"
        }
    ]
})

let copyWebpack_for_renderer = new CopyWebpackPlugin({
    patterns:[
        {
            from:"./**/*.css",
            to:"./renderer",
            context:"./src/renderer"
        }
    ]
});

let htmlWebpackPlugin_for_renderer_development = new HtmlWebpackPlugin({
    template: './src/template/index.html',
    filename:"[name].html",
    meta:[
        {
            'http-equiv':"Content-Security-Policy",
            'content':"script-src 'self' 'unsafe-eval';"
        }
    ]

});

let htmlWebpackPlugin_for_renderer_production = new HtmlWebpackPlugin({
    template: './src/template/index.html',
    filename:"[name].html",
    meta:[
        {
            'http-equiv':"Content-Security-Policy",
            'content':"script-src 'self';"
        }
    ]

});

let for_main = {
    target: "electron-main",
    entry:{
        "main/main": "./src/main/main.ts",
        "main/preload": "./src/main/preload.ts"
    },
    output:{
        path: path.resolve(__dirname,"dist"),
        filename:"[name].js"
    },
    module:{
        rules:[
            {test: /\.ts$/, use: "ts-loader"}
        ]
    },
    resolve: {
        extensions: [".ts"]
    },
    plugins: [copyWebpack_for_main]
}

let for_renderer = {
    target: "electron-renderer",
    entry:{
        "renderer/renderer": "./src/renderer/renderer.ts"
    },
    output: {
        path: path.resolve(__dirname,"dist"),
        filename: "[name].js"
    },
    module:{
        rules:[{
            test: /\.vue$/,
            loader: 'vue-loader',
            options: {
                loaders:{
                    'scss': 'vue-style-loader!css-loader!sass-loader',
                    'sass': 'vue-style-loader!css-loader!sass-loader?indentedSyntax',
                }
            }
        },{
            test: /\.ts$/,
            loader: "ts-loader",
            exclude: /node_modules/,
            options: {
                appendTsSuffixTo: [/\.vue$/],
            }
        },{
            test: /\.css$/,
            use:[
                "vue-style-loader",
                'css-loader'
            ]
        }]
    },
    resolve:{
        extensions:[".ts",".js",".vue"],
        alias:{
            vue: "vue/dist/vue.runtime.esm.js"
        }
    },
    plugins:[new VueLoaderPlugin(), copyWebpack_for_renderer]
}


module.exports = (env) => {
    switch (env.mode) {
        case 'prod':
            return [
                merge(for_main, {mode:'production'}),
                merge(for_renderer, {mode:'production', plugins: [htmlWebpackPlugin_for_renderer_production]})
            ];
        case 'dev':
            return [
                merge(for_main, {mode:'development', devtool: 'inline-source-map'}),
                merge(for_renderer, {mode:'development', devtool: 'inline-source-map', plugins: [htmlWebpackPlugin_for_renderer_development]})
            ];
    }
}